@@ -415,6 +415,8 @@ def main():
         sys.exit(1)
     ec2.terminate_cluster(check_cascading_options('aws_access_key_id'), check_cascading_options('aws_secret_access_key'), check_cascading_options('handle'), prompt_continuation=True)
 
+    start_time = time.time()
+
     # Get basic information for both Community and Enterprise clusters
     clustername = check_cascading_options('clustername')
     clustername = clustername.replace("'", "").replace(' ', '') # AMI 2.2 will allow spaces
@@ -509,6 +511,10 @@ def main():
         print '{0} -i {1} -o UserKnownHostsFile={2} {3}@{4}'.format(config.get('System', 'ssh'), PEM_FILE, HOST_FILE, user, node)
     print
 
+    end_time = int(time.time() - start_time)
+    print 'Total Elapsed Time: %s minutes %s seconds' % (end_time / 60, end_time % 60)
+    print
+
     ec2.terminate_cluster(check_cascading_options('aws_access_key_id'), check_cascading_options('aws_secret_access_key'), check_cascading_options('handle'))
 
 def run():
